@@ -1,10 +1,12 @@
 # noinspection PyMissingOrEmptyDocstring
 import atexit
 import copy
+import multiprocessing
 import queue
 import re
 import sys
 import os
+import threading
 import traceback
 import socket
 import datetime
@@ -433,7 +435,6 @@ class ColorHandler(logging.Handler):
             stream = sys.stdout  # stderr无彩。
         self.stream = stream
         self._display_method = 7 if os_name == 'posix' else 0
-        self._word_color = 37 if os_name == 'posix' else 37
 
     def flush(self):
         """
@@ -451,19 +452,19 @@ class ColorHandler(logging.Handler):
         if record_level == 10:
             # msg_color = ('\033[0;32m%s\033[0m' % msg)  # 绿色
             # print(msg1)
-            msg_color = f'\033[0;32m{assist_msg}\033[0m \033[0;{self._word_color};42m{effective_information_msg}\033[0m'  # 绿色
+            msg_color = f'\033[0;32m{assist_msg}\033[0m \033[0;37;42m{effective_information_msg}\033[0m'  # 绿色
         elif record_level == 20:
             # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.bule, msg))  # 青蓝色 36    96
-            msg_color = f'\033[0;36m{assist_msg}\033[0m \033[0;{self._word_color};46m{effective_information_msg}\033[0m'
+            msg_color = f'\033[0;36m{assist_msg}\033[0m \033[0;37;46m{effective_information_msg}\033[0m'
         elif record_level == 30:
             # msg_color = ('\033[%s;%sm%s\033[0m' % (self._display_method, self.yellow, msg))
-            msg_color = f'\033[0;33m{assist_msg}\033[0m \033[0;{self._word_color};43m{effective_information_msg}\033[0m'
+            msg_color = f'\033[0;33m{assist_msg}\033[0m \033[0;37;43m{effective_information_msg}\033[0m'
         elif record_level == 40:
             # msg_color = ('\033[%s;35m%s\033[0m' % (self._display_method, msg))  # 紫红色
-            msg_color = f'\033[0;35m{assist_msg}\033[0m \033[0;{self._word_color};45m{effective_information_msg}\033[0m'
+            msg_color = f'\033[0;35m{assist_msg}\033[0m \033[0;37;45m{effective_information_msg}\033[0m'
         elif record_level == 50:
             # msg_color = ('\033[%s;31m%s\033[0m' % (self._display_method, msg))  # 血红色
-            msg_color = f'\033[0;31m{assist_msg}\033[0m \033[0;{self._word_color};41m{effective_information_msg}\033[0m'
+            msg_color = f'\033[0;31m{assist_msg}\033[0m \033[0;37;41m{effective_information_msg}\033[0m'
         else:
             msg_color = f'{assist_msg}  {effective_information_msg}'
         return msg_color
@@ -495,19 +496,19 @@ class ColorHandler(logging.Handler):
         background_color = ''
         complete_color = ''
         if record_level == 10:
-            background_color = f'[0;{self._word_color};42m'
+            background_color = f'[0;30;42m'
             complete_color = f'[0;32m'
         elif record_level == 20:
-            background_color = f'[0;{self._word_color};46m'
+            background_color = f'[0;30;46m'
             complete_color = f'[0;36m'
         elif record_level == 30:
-            background_color = f'[0;{self._word_color};43m'
+            background_color = f'[0;30;43m'
             complete_color = f'[0;33m'
         elif record_level == 40:
-            background_color = f'[0;{self._word_color};45m'
+            background_color = f'[0;37;45m'
             complete_color = f'[0;35m'
         elif record_level == 50:
-            background_color = f'[0;{self._word_color};41m'
+            background_color = f'[0;37;41m'
             complete_color = f'[0;31m'
         record_copy.msg = f'\033{background_color}{record_copy.msg}\033[0m'
         msg_color_without = self.format(record_copy)
@@ -519,6 +520,35 @@ class ColorHandler(logging.Handler):
         # print(repr(msg_color))
         return msg_color
 
+    def __build_color_msg_with_backgroud_color3333(self, record_level, record_copy: logging.LogRecord, ):
+        background_color = ''
+        complete_color = ''
+        if record_level == 10:
+            background_color = f'[0;30;42m'
+            complete_color = f'[0;32m'
+        elif record_level == 20:
+            background_color = f'[0;30;46m'
+            complete_color = f'[0;36m'
+        elif record_level == 30:
+            background_color = f'[0;30;43m'
+            complete_color = f'[0;33m'
+        elif record_level == 40:
+            background_color = f'[0;37;45m'
+            complete_color = f'[0;35m'
+        elif record_level == 50:
+            background_color = f'[0;37;41m'
+            complete_color = f'[0;31m'
+        record_copy.msg = f'\033{complete_color}{record_copy.msg}\033[0m'
+        msg_color_without = self.format(record_copy)
+        # print(repr(msg_color))
+        if isinstance(self.formatter, JsonFormatter) and background_color:  # json会把/033 转义成\u001b,导致颜色显示不出来。
+            msg_color_without = msg_color_without.replace(rf'\u001b{background_color}', f'\033{background_color}')
+            msg_color_without = msg_color_without.replace(r'\u001b[0m', f'\033[0m\033{complete_color}')
+        # msg_color = f'\033{complete_color}{msg_color_without}\033[0m'
+        msg_color = f'\033{background_color}{msg_color_without}\033[0m'
+        # print(repr(msg_color))
+        return msg_color
+
     def __build_color_msg_with_no_backgroud_color(self, record_level, record_copy: logging.LogRecord, ):
         complete_msg = self.format(record_copy)
         if record_level == 10:
@@ -703,8 +733,10 @@ class ConcurrentRotatingFileHandlerWithBufferInitiativeLinux00000000(ConcurrentR
         with self.__lock_for_rotate:
             self._rollover_and_do_write()
 
+
 ConcurrentRotatingFileHandlerWithBufferInitiativeLinux = ConcurrentRotatingFileHandler
 
+
 class CompatibleSMTPSSLHandler(handlers.SMTPHandler):
     """
     官方的SMTPHandler不支持SMTP_SSL的邮箱，这个可以两个都支持,并且支持邮件发送频率限制
@@ -851,8 +883,7 @@ class DingTalkHandler(logging.Handler):
                     logging.getLogger(logger_name).handlers.pop(index)
 
 
-# noinspection PyPep8Naming
-class ConcurrentDayRotatingFileHandler(logging.Handler):
+class ConcurrentDayRotatingFileHandlerWin(logging.Handler):
     """
     这个多进程按时间切片安全的。
     官方的 TimedRotatingFileHandler 在多进程下疯狂报错，
@@ -909,6 +940,7 @@ class ConcurrentDayRotatingFileHandler(logging.Handler):
     def _write_to_file(self):
         buffer_msgs = ''
         while True:
+            # print(self.buffer_msgs_queue.qsize())
             try:
                 msg = self.buffer_msgs_queue.get(block=False)
                 buffer_msgs += msg + '\n'
@@ -954,3 +986,177 @@ class ConcurrentDayRotatingFileHandler(logging.Handler):
         # print(result)
         for r in result:
             Path(r).unlink()
+
+
+class ConcurrentDayRotatingFileHandlerLinux(logging.Handler):
+    def __init__(self, file_name: str, file_path: str, back_count=10):
+        super().__init__()
+        self.file_name = file_name
+        self.file_path = file_path
+        self.backupCount = back_count
+        self.extMatch = re.compile(r"^\d{4}-\d{2}-\d{2}(\.\w+)?$", re.ASCII)
+        self.extMatch2 = re.compile(r"^\d{2}-\d{2}-\d{2}(\.\w+)?$", re.ASCII)
+        self._last_delete_time = time.time()
+
+        time_str = time.strftime('%Y-%m-%d')
+        # time_str = time.strftime('%H-%M-%S')  # 方便测试用的，方便观察。
+        new_file_name = self.file_name + '.' + time_str
+        path_obj = Path(self.file_path) / Path(new_file_name)
+        path_obj.touch(exist_ok=True)
+        self.fp = open(path_obj, 'a', encoding='utf-8')
+        self.time_str = time_str
+        self._lock = multiprocessing.Lock()
+
+    def _get_fp(self):
+        with self._lock:
+            time_str = time.strftime('%Y-%m-%d')
+            # time_str = time.strftime('%H-%M-%S')  # 方便测试用的，方便观察。
+            if time_str != self.time_str:
+                try:
+                    self.fp.close()
+                except Exception as e:
+                    print(e)
+                new_file_name = self.file_name + '.' + time_str
+                path_obj = Path(self.file_path) / Path(new_file_name)
+                path_obj.touch(exist_ok=True)
+                self.fp = open(path_obj, 'a', encoding='utf-8')
+
+    def emit(self, record: logging.LogRecord):
+        """
+        emit已经在logger的handle方法中加了锁，所以这里的重置上次写入时间和清除buffer_msgs不需要加锁了。
+        :param record:
+        :return:
+        """
+        # noinspection PyBroadException
+        try:
+            msg = self.format(record)
+            self.fp.write(msg + '\n')
+        except Exception:
+            self.handleError(record)
+        if time.time() - self._last_delete_time > 60:
+            self._get_fp()
+            self._find_and_delete_files()
+            self._last_delete_time = time.time()
+
+    def _find_and_delete_files(self):
+        """
+        这一段命名不规范是复制原来的官方旧代码。
+        Determine the files to delete when rolling over.
+
+        More specific than the earlier method, which just used glob.glob().
+        """
+        dirName = self.file_path
+        baseName = self.file_name
+        fileNames = os.listdir(dirName)
+        result = []
+        prefix = baseName + "."
+        plen = len(prefix)
+        for fileName in fileNames:
+            if fileName[:plen] == prefix:
+                suffix = fileName[plen:]
+                # print(fileName, prefix,suffix)
+                if self.extMatch.match(suffix) or self.extMatch2.match(suffix):
+                    result.append(os.path.join(dirName, fileName))
+        if len(result) < self.backupCount:
+            result = []
+        else:
+            result.sort()
+            result = result[:len(result) - self.backupCount]
+        # print(result)
+        for r in result:
+            Path(r).unlink()
+
+
+class ConcurrentSecondRotatingFileHandlerLinux(logging.Handler):
+    """ 按秒切割的多进程安全文件日志，方便测试验证"""
+    def __init__(self, file_name: str, file_path: str, back_count=10):
+        super().__init__()
+        self.file_name = file_name
+        self.file_path = file_path
+        self.backupCount = back_count
+        self.extMatch = re.compile(r"^\d{4}-\d{2}-\d{2}(\.\w+)?$", re.ASCII)
+        self.extMatch2 = re.compile(r"^\d{2}-\d{2}-\d{2}(\.\w+)?$", re.ASCII)
+        self._last_delete_time = time.time()
+
+
+        time_str = time.strftime('%H-%M-%S')  # 方便测试用的，方便观察。
+        new_file_name = self.file_name + '.' + time_str
+        path_obj = Path(self.file_path) / Path(new_file_name)
+        path_obj.touch(exist_ok=True)
+        self.fp = open(path_obj, 'a', encoding='utf-8')
+        self.time_str = time_str
+        self._lock = multiprocessing.Lock()
+
+    def _get_fp(self):
+        with self._lock:
+            time_str = time.strftime('%H-%M-%S')
+            # time_str = time.strftime('%H-%M-%S')  # 方便测试用的，方便观察。
+            if time_str != self.time_str:
+                try:
+                    pass
+                    # self.fp.close()
+                except Exception as e:
+                    print(e)
+                new_file_name = self.file_name + '.' + time_str
+                path_obj = Path(self.file_path) / Path(new_file_name)
+                path_obj.touch(exist_ok=True)
+                self.fp = open(path_obj, 'a', encoding='utf-8')
+
+    def emit(self, record: logging.LogRecord):
+        """
+        emit已经在logger的handle方法中加了锁，所以这里的重置上次写入时间和清除buffer_msgs不需要加锁了。
+        :param record:
+        :return:
+        """
+        # noinspection PyBroadException
+        try:
+            msg = self.format(record)
+            self.fp.write(msg + '\n')
+            if time.time() - self._last_delete_time > 0.5:
+                self._get_fp()
+                self._find_and_delete_files()
+                self._last_delete_time = time.time()
+        except Exception as e:
+            print(e)
+            self.handleError(record)
+
+
+    def _find_and_delete_files(self):
+        """
+        这一段命名不规范是复制原来的官方旧代码。
+        Determine the files to delete when rolling over.
+
+        More specific than the earlier method, which just used glob.glob().
+        """
+        dirName = self.file_path
+        baseName = self.file_name
+        fileNames = os.listdir(dirName)
+        result = []
+        prefix = baseName + "."
+        plen = len(prefix)
+        for fileName in fileNames:
+            if fileName[:plen] == prefix:
+                suffix = fileName[plen:]
+                # print(fileName, prefix,suffix)
+                if self.extMatch.match(suffix) or self.extMatch2.match(suffix):
+                    result.append(os.path.join(dirName, fileName))
+        if len(result) < self.backupCount:
+            result = []
+        else:
+            result.sort()
+            result = result[:len(result) - self.backupCount]
+        # print(result)
+        for r in result:
+            try:
+                Path(r).unlink()
+                print(f'删除成功 {r}')
+            except (PermissionError,FileNotFoundError) as e:
+                print(e)
+
+
+
+ConcurrentDayRotatingFileHandler = ConcurrentDayRotatingFileHandlerWin if os_name == 'nt' else ConcurrentDayRotatingFileHandlerLinux
+
+# ConcurrentDayRotatingFileHandler = ConcurrentSecondRotatingFileHandlerLinux
+#
+# print(ConcurrentDayRotatingFileHandler)
